<?php

namespace Drupal\Tests\photoswipe_dynamic_caption\FunctionalJavascript;

use Drupal\Tests\photoswipe\FunctionalJavascript\PhotoswipeJsTestBase;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Tests the photoswipe_dynamic_caption module.
 *
 * @group photoswipe
 */
class CaptionTest extends PhotoswipeJsTestBase {
  use TestFileCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'test_page_test',
    'file',
    'image',
    'node',
    'field_ui',
    'photoswipe',
    'photoswipe_dynamic_caption',
  ];

  /**
   * Tests if caption is visible.
   */
  public function testPhotoswipeFieldFormatterOnNodeDisplay() {
    $session = $this->assertSession();
    $page = $this->getSession()->getPage();

    $this->createImageField('field_test', 'node', 'article', [
      'uri_scheme' => 'public',
      'required' => 'true',
    ], ['alt_field_required' => 1]);
    $this->drupalGet('node/add/article');
    $page->fillField('title[0][value]', 'My test content');
    $this->assertNotEmpty($image_upload_field = $page->find('css', '#edit-field-test-0-upload'));
    $image_upload_field->attachFile($this->container->get('file_system')->realpath($this->getTestFiles('image')[0]->uri));
    $session->waitForElementVisible('css', '.image-preview');

    $alt_text = 'Alt text';
    $page->fillField('Alternative text', $alt_text);
    $page->pressButton('edit-submit');
    $this->drupalGet('/node/1');

    $session->waitForElement('css', '.photoswipe-gallery.photoswipe-gallery--fallback-wrapper');
    // Open the photoswipe layer.
    $this->getSession()->getPage()->find('css', 'a[href*="image-test.png"].photoswipe')->click();
    $session->waitForElementVisible('css', '.pswp');
    $session->elementTextEquals('css', '.pswp__dynamic-caption', $alt_text);
  }

}
