<?php

namespace Drupal\Tests\photoswipe\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * This class provides methods specifically for testing something.
 *
 * @group photoswipe
 */
class PhotoswipeSettingsTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'photoswipe',
    'node',
    'test_page_test',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests functionality of the settings page.
   */
  public function testSettingsChange() {
    $session = $this->assertSession();
    $page = $this->getSession()->getPage();
    // Go to the settings page:
    $this->drupalGet('/admin/config/media/photoswipe');
    $session->statusCodeEquals(200);
    // Check if the default settings are present:
    $page->hasUncheckedField('enable_cdn');
    $page->hasUncheckedField('photoswipe_always_load_non_admin');
    $session->fieldValueEquals('options_showAnimationDuration', 333);
    $session->fieldValueEquals('options_hideAnimationDuration', 333);
    $session->fieldValueEquals('options_zoomAnimationDuration', 333);
    $session->fieldValueEquals('options_maxWidthToAnimate', 4000);
    $session->fieldValueEquals('options_easing', 'cubic-bezier(.4,0,.22,1)');
    $session->fieldValueEquals('options_bgOpacity', 0.8);
    $session->fieldValueEquals('options_spacing', 0.1);
    $session->fieldValueEquals('options_maxZoomLevel', 4);
    $page->hasCheckedField('options_allowPanToNext');
    $page->hasCheckedField('options_loop');
    $page->hasCheckedField('options_pinchToClose');
    $page->hasCheckedField('options_clickToCloseNonZoomable');
    $page->hasCheckedField('options_closeOnVerticalDrag');
    $page->hasCheckedField('options_returnFocus');
    $page->hasCheckedField('options_escKey');
    $page->hasCheckedField('options_arrowKeys');
    $session->fieldValueEquals('options_imageClickAction', 'zoom-or-close');
    $session->fieldValueEquals('options_tapAction', 'toggle-controls');
    $session->fieldValueEquals('options_doubleTapAction', 'zoom');
    $session->fieldValueEquals('options_bgClickAction', 'close');
    $session->fieldValueEquals('options_indexIndicatorSep', ' / ');
    $session->fieldValueEquals('options_errorMsg', 'The image could not be loaded.');
    $session->fieldValueEquals('options_preloadBefore', 1);
    $session->fieldValueEquals('options_preloadAfter', 2);
    $session->fieldValueEquals('options_preloaderDelay', 2000);
    // Change the settings values:
    $page->checkField('enable_cdn');
    $page->checkField('photoswipe_always_load_non_admin');
    $page->fillField('options_showAnimationDuration', 12345);
    $page->fillField('options_hideAnimationDuration', 12345);
    $page->fillField('options_zoomAnimationDuration', 12345);
    $page->fillField('options_maxWidthToAnimate', 12345);
    $page->fillField('options_easing', '12345');
    $page->fillField('options_bgOpacity', 0.12);
    $page->fillField('options_spacing', 0.12);
    $page->fillField('options_maxZoomLevel', 12.3);
    $page->uncheckField('options_allowPanToNext');
    $page->uncheckField('options_loop');
    $page->uncheckField('options_pinchToClose');
    $page->uncheckField('options_clickToCloseNonZoomable');
    $page->uncheckField('options_closeOnVerticalDrag');
    $page->uncheckField('options_returnFocus');
    $page->uncheckField('options_escKey');
    $page->uncheckField('options_arrowKeys');
    $page->selectFieldOption('options_imageClickAction', 'close');
    $page->selectFieldOption('options_tapAction', 'close');
    $page->selectFieldOption('options_doubleTapAction', 'close');
    $page->selectFieldOption('options_bgClickAction', 'zoom');
    $page->fillField('options_indexIndicatorSep', '12345');
    $page->fillField('options_errorMsg', '12345');
    $page->fillField('options_preloadBefore', 12345);
    $page->fillField('options_preloadAfter', 12345);
    $page->fillField('options_preloaderDelay', 12345);
    // Submit the settings and re-enter the settings page:
    $page->pressButton('edit-submit');
    $session->statusCodeEquals(200);
    $this->drupalGet('/admin/config/media/photoswipe');
    $session->statusCodeEquals(200);
    // Check if the settings have changed accordingly:
    $page->hasCheckedField('enable_cdn');
    $page->hasCheckedField('photoswipe_always_load_non_admin');
    $session->fieldValueEquals('options_showAnimationDuration', 12345);
    $session->fieldValueEquals('options_hideAnimationDuration', 12345);
    $session->fieldValueEquals('options_zoomAnimationDuration', 12345);
    $session->fieldValueEquals('options_maxWidthToAnimate', 12345);
    $session->fieldValueEquals('options_easing', '12345');
    $session->fieldValueEquals('options_bgOpacity', 0.12);
    $session->fieldValueEquals('options_spacing', 0.12);
    $session->fieldValueEquals('options_maxZoomLevel', 12.3);
    $page->hasUncheckedField('options_allowPanToNext');
    $page->hasUncheckedField('options_loop');
    $page->hasUncheckedField('options_pinchToClose');
    $page->hasUncheckedField('options_clickToCloseNonZoomable');
    $page->hasUncheckedField('options_closeOnVerticalDrag');
    $page->hasUncheckedField('options_returnFocus');
    $page->hasUncheckedField('options_escKey');
    $page->hasUncheckedField('options_arrowKeys');
    $session->fieldValueEquals('options_imageClickAction', 'close');
    $session->fieldValueEquals('options_tapAction', 'close');
    $session->fieldValueEquals('options_doubleTapAction', 'close');
    $session->fieldValueEquals('options_bgClickAction', 'zoom');
    $session->fieldValueEquals('options_indexIndicatorSep', '12345');
    $session->fieldValueEquals('options_errorMsg', '12345');
    $session->fieldValueEquals('options_preloadBefore', 12345);
    $session->fieldValueEquals('options_preloadAfter', 12345);
    $session->fieldValueEquals('options_preloaderDelay', 12345);
  }

}
